@@ -10,8 +10,11 @@ class TestLookup:
             sector.get_code("gestion des sites daccueil temporaires") == "SHL"
         )
         assert "Intersectoral" in sector.get_code_to_name()
+        assert sector.get_name("PRO-MIN") == "Mine Action"
+        assert sector.get_name("xxx") is None
 
     def test_org_type(self, configuration):
         org_type = OrgType()
         assert org_type.get_code("embassy") == "434"
         assert org_type.get_code("ong int") == "437"
+        assert org_type.get_name("xxx", "") == ""
